@@ -1,5 +1,6 @@
 ###########################################################################/**
 # @RdocClass ChecksumFile
+# @aliasmethod getChecksum
 #
 # @title "The ChecksumFile class"
 #
@@ -61,6 +62,10 @@ setMethodS3("isOld", "ChecksumFile", function(this, ...) {
 })
 
 
+setMethodS3("getChecksum", "ChecksumFile", function(this, write=FALSE, ...) {
+  NextMethod("getChecksum", write=write)
+})
+
 
 ###########################################################################/**
 # @RdocMethod readChecksum
