@@ -1,4 +1,4 @@
-library("R.filesets")
+source("incl/start.R")
 
 message("*** ChecksumFile / ChecksumFileSet")
 
@@ -31,5 +31,23 @@ validate(dsCZ, verbose=TRUE)
 
 print(readChecksums(dsCZ))
 
+## Single checksum file
+dfC <- dsC[[1]]
+print(dfC)
+dfCZ <- getChecksumFile(dfC)
+print(dfCZ)
+
+pathnameZZ <- sprintf("%s.md5", getPathname(dfCZ))
+print(file.info(pathnameZZ))
+stopifnot(!isFile(pathnameZZ))
+
+## Calling getChecksum() on an *.md5 file should not
+## create an *.md5.md5 file
+print(getChecksum(dfCZ))
+print(file.info(pathnameZZ))
+stopifnot(!isFile(pathnameZZ))
+
 
 message("*** ChecksumFile / ChecksumFileSet ... DONE")
+
+source("incl/end.R")
